kedro.extras.datasets — Kedro 0.17.6 documentation

# kedro.extras.datasets

Description

`kedro.extras.datasets` is where you can find all of Kedro’s data connectors. These data connectors are implementations of the `AbstractDataSet`.

Classes

`kedro.extras.datasets.api.APIDataSet`(url[, …]) | `APIDataSet` loads the data from HTTP(S) APIs.
`kedro.extras.datasets.biosequence.BioSequenceDataSet`(…) | `BioSequenceDataSet` loads and saves data to a sequence file.
`kedro.extras.datasets.dask.ParquetDataSet`(…) | `ParquetDataSet` loads and saves data to parquet file(s).
`kedro.extras.datasets.email.EmailMessageDataSet`(…) | `EmailMessageDataSet` loads/saves an email message from/to a file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.geopandas.GeoJSONDataSet`(…) | `GeoJSONDataSet` loads/saves data to a GeoJSON file using an underlying filesystem (eg: local, S3, GCS).
`kedro.extras.datasets.holoviews.HoloviewsWriter`(…) | `HoloviewsWriter` saves Holoviews objects to image file(s) in an underlying filesystem (e.g.
`kedro.extras.datasets.json.JSONDataSet`(filepath) | `JSONDataSet` loads/saves data from/to a JSON file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.matplotlib.MatplotlibWriter`(…) | `MatplotlibWriter` saves one or more Matplotlib objects as image files to an underlying filesystem (e.g.
`kedro.extras.datasets.networkx.NetworkXDataSet`(…) | `NetworkXDataSet` loads and saves graphs to a JSON file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.pandas.CSVDataSet`(filepath) | `CSVDataSet` loads/saves data from/to a CSV file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.pandas.ExcelDataSet`(…) | `ExcelDataSet` loads/saves data from/to a Excel file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.pandas.AppendableExcelDataSet`(…) | `AppendableExcelDataSet` loads/saves data from/to a local Excel file opened in append mode.
`kedro.extras.datasets.pandas.FeatherDataSet`(…) | `FeatherDataSet` loads and saves data to a feather file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.pandas.GBQQueryDataSet`([…]) | `GBQQueryDataSet` loads data from a provided SQL query from Google BigQuery.
`kedro.extras.datasets.pandas.GBQTableDataSet`(…) | `GBQTableDataSet` loads and saves data from/to Google BigQuery.
`kedro.extras.datasets.pandas.GenericDataSet`(…) | pandas.GenericDataSet loads/saves data from/to a data file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.pandas.HDFDataSet`(…) | `HDFDataSet` loads/saves data from/to a hdf file using an underlying filesystem (e.g.
`kedro.extras.datasets.pandas.JSONDataSet`(…) | `JSONDataSet` loads/saves data from/to a JSON file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.pandas.ParquetDataSet`(…) | `ParquetDataSet` loads/saves data from/to a Parquet file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.pandas.SQLQueryDataSet`([…]) | `SQLQueryDataSet` loads data from a provided SQL query.
`kedro.extras.datasets.pandas.SQLTableDataSet`(…) | `SQLTableDataSet` loads data from a SQL table and saves a pandas dataframe to a table.
`kedro.extras.datasets.pickle.PickleDataSet`(…) | `PickleDataSet` loads/saves data from/to a Pickle file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.pillow.ImageDataSet`(…) | `ImageDataSet` loads/saves image data as numpy from an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.plotly.JSONDataSet`(…) | `JSONDataSet` loads/saves a plotly figure from/to a JSON file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.plotly.PlotlyDataSet`(…) | `PlotlyDataSet` generates a plot from a pandas DataFrame and saves it to a JSON file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.spark.DeltaTableDataSet`(…) | `DeltaTableDataSet` loads data into DeltaTable objects.
`kedro.extras.datasets.spark.SparkDataSet`(…) | `SparkDataSet` loads and saves Spark dataframes.
`kedro.extras.datasets.spark.SparkHiveDataSet`(…) | `SparkHiveDataSet` loads and saves Spark dataframes stored on Hive.
`kedro.extras.datasets.spark.SparkJDBCDataSet`(…) | `SparkJDBCDataSet` loads data from a database table accessible via JDBC URL url and connection properties and saves the content of a PySpark DataFrame to an external database table via JDBC.
`kedro.extras.datasets.tensorflow.TensorFlowModelDataset`(…) | `TensorflowModelDataset` loads and saves TensorFlow models.
`kedro.extras.datasets.text.TextDataSet`(filepath) | `TextDataSet` loads/saves data from/to a text file using an underlying filesystem (e.g.: local, S3, GCS)
`kedro.extras.datasets.tracking.JSONDataSet`(…) | `JSONDataSet` saves data to a JSON file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.tracking.MetricsDataSet`(…) | `MetricsDataSet` saves data to a JSON file using an underlying filesystem (e.g.: local, S3, GCS).
`kedro.extras.datasets.yaml.YAMLDataSet`(filepath) | `YAMLDataSet` loads/saves data from/to a YAML file using an underlying filesystem (e.g.: local, S3, GCS).